@@ -65,29 +65,8 @@ require AutoLoader;
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
 
-our $VERSION = '2.09';
+our $VERSION = '2.10';
 
-sub AUTOLOAD {
-	# This AUTOLOAD is used to 'autoload' constants from the constant()
-	# XS function.  If a constant is not found then control is passed
-	# to the AUTOLOAD in AutoLoader.
-
-	my $constname;
-	($constname = $AUTOLOAD) =~ s/.*:://;
-	croak '& not defined' if $constname eq 'constant';
-	my $val = constant($constname, @_ ? $_[0] : 0);
-	if ($! != 0) {
-		if ($! =~ /Invalid/) {
-			$AutoLoader::AUTOLOAD = $AUTOLOAD;
-			goto &AutoLoader::AUTOLOAD;
-		} else {
-			croak "Your vendor has not defined Math::GMP macro $constname";
-		}
-	}
-	no strict 'refs';			## no critic
-	*$AUTOLOAD = sub () { $val };
-	goto &$AUTOLOAD;
-}
 
 bootstrap Math::GMP $VERSION;
 
@@ -106,17 +85,18 @@ sub new {
 	my $ival = shift || 0;
 	my $base = shift;
 
-	$ival =~ s/^\+//;
-	$ival =~ s/[ _]//g;
-	my $ret;
+	$ival =~ s/\A\+//;
+	$ival =~ tr/ _//d;
 	if ($base) {
-		$ret = Math::GMP::new_from_scalar_with_base($ival, $base);
-	} else {
-		$ival = 0 if $ival =~ /[^\d\-xA-Fa-f]/;
-		$ret = Math::GMP::new_from_scalar($ival);
+		return Math::GMP::new_from_scalar_with_base($ival, $base);
+	}
+    else {
+		if ($ival =~ /[^\d\-xA-Fa-f]/)
+        {
+            die "Argument to Math::GMP->new is not a string representing an integer";
+        }
+		return Math::GMP::new_from_scalar($ival);
 	}
-
-	return $ret;
 }
 
 BEGIN
@@ -126,15 +106,6 @@ BEGIN
 		*lcm = \&blcm;
 	}
 
-sub add {
-	croak 'add: not enough arguments, two required' if @_ < 2;
-
-	my $ret = Math::GMP->new(0);
-	add_to_self($ret, shift) while @_;
-
-	return $ret;
-}
-
 __END__
 
 =pod
@@ -147,7 +118,7 @@ Math::GMP - High speed arbitrary size integer math
 
 =head1 VERSION
 
-version 2.09
+version 2.10
 
 =head1 SYNOPSIS
 
@@ -185,6 +156,32 @@ doubles to compute the 250,000 bit number, and thereby overflow it
 into meaninglessness (smaller exponents yield less accurate data due
 to floating point rounding).
 
+=begin Removed
+
+sub AUTOLOAD {
+	# This AUTOLOAD is used to 'autoload' constants from the constant()
+	# XS function.  If a constant is not found then control is passed
+	# to the AUTOLOAD in AutoLoader.
+
+	my $constname;
+	($constname = $AUTOLOAD) =~ s/.*:://;
+	croak '& not defined' if $constname eq 'constant';
+	my $val = constant($constname, @_ ? $_[0] : 0);
+	if ($! != 0) {
+		if ($! =~ /Invalid/) {
+			$AutoLoader::AUTOLOAD = $AUTOLOAD;
+			goto &AutoLoader::AUTOLOAD;
+		} else {
+			croak "Your vendor has not defined Math::GMP macro $constname";
+		}
+	}
+	no strict 'refs';			## no critic
+	*$AUTOLOAD = sub () { $val };
+	goto &$AUTOLOAD;
+}
+
+=end Removed
+
 =head1 METHODS
 
 Although the non-overload interface is not complete, the following
@@ -209,29 +206,30 @@ be represented in the base specified by the second parameter.
 
 Calculates the factorial of $x and returns the result.
 
-=head2 band
+=head2 my $val = $x->band($y, $swap)
 
   $x = Math::GMP->new(6);
-  $x->band(3);      # 0b110 & 0b11 = 1
+  my $val = $x->band(3, 0);      # 0b110 & 0b11 = 1
+  print $val;
 
-Calculates the bit-wise AND of its two arguments and modifies the first
-argument.
+Calculates the bit-wise AND of its two arguments and returns the result.
+$swap should be provided but is ignored.
 
-=head2 bxor
+=head2 my $ret = $x->bxor($y, $swap);
 
   $x = Math::GMP->new(6);
-  $x->bxor(3);      # 0b110 & 0b11 = 0b101
+  my $val = $x->bxor(3, 0);      # 0b110 ^ 0b11 = 0b101
+  print $val;
 
-Calculates the bit-wise XOR of its two arguments and modifies the first
-argument.
+Calculates the bit-wise XOR of its two arguments and returns the result.
 
-=head2 bior
+=head2 my $ret = $x->bior($y, $swap);
 
   $x = Math::GMP->new(6);
-  $x->bior(3);      # 0b110 & 0b11 = 0b111
+  my $val = $x->bior(3);      # 0b110 | 0b11 = 0b111
+  print $val;
 
-Calculates the bit-wise OR of its two arguments and modifies the first
-argument.
+Calculates the bit-wise OR of its two arguments and returns the result.
 
 =head2 blshift
 
@@ -253,22 +251,26 @@ result. Second argument is swap.
 
 =head2 bgcd
 
-  $x = Math::GMP->new(6);
-  $x->bgcd(4);      # 6 / 2 = 2, 4 / 2 = 2 => 2
+  my $x = Math::GMP->new(6);
+  my $gcd = $x->bgcd(4);
+  # 6 / 2 = 3, 4 / 2 = 2 => 2
+  print $gcd
 
 Returns the Greatest Common Divisor of the two arguments.
 
 =head2 blcm
 
-  $x = Math::GMP->new(6);
-  $x->blcm(4);      # 6 * 2 = 12, 4 * 3 = 12 => 12
+  my $x = Math::GMP->new(6);
+  my $lcm = $x->blcm(4);      # 6 * 2 = 12, 4 * 3 = 12 => 12
+  print $lcm;
 
 Returns the Least Common Multiple of the two arguments.
 
 =head2 bmodinv
 
-  $x = Math::GMP->new(5);
-  $x->bmodinv(7);   # 5 * 3 == 1 (mod 7) => 3
+  my $x = Math::GMP->new(5);
+  my $modinv = $x->bmodinv(7);   # 5 * 3 == 1 (mod 7) => 3
+  print $modinv;
 
 Returns the modular inverse of $x (mod $y), if defined. This currently
 returns 0 if there is no inverse (but that may change in the future).
@@ -276,15 +278,16 @@ Behaviour is undefined when $y is 0.
 
 =head2 bsqrt
 
-  $x = Math::GMP->new(6);
-  $x->bsqrt();      # int(sqrt(6)) => 2
+  my $x = Math::GMP->new(6);
+  my $root = $x->bsqrt();      # int(sqrt(6)) => 2
+  print $root;
 
 Returns the integer square root of its argument.
 
 =head2 legendre
 
   $x = Math::GMP->new(6);
-  $x->legendre(3);
+  my $ret = $x->legendre(3);
 
 Returns the value of the Legendre symbol ($x/$y). The value is defined only
 when $y is an odd prime; when the value is not defined, this currently
@@ -292,8 +295,8 @@ returns 0 (but that may change in the future).
 
 =head2 jacobi
 
-  $x = Math::GMP->new(6);
-  $x->jacobi(3);
+  my $x = Math::GMP->new(6);
+  my $jacobi_verdict = $x->jacobi(3);
 
 Returns the value of the Jacobi symbol ($x/$y). The value is defined only
 when $y is odd; when the value is not defined, this currently returns 0
@@ -301,19 +304,69 @@ when $y is odd; when the value is not defined, this currently returns 0
 
 =head2 fibonacci
 
-  $x = Math::GMP::fibonacci(16);
+  my $fib = Math::GMP::fibonacci(16);
 
 Calculates the n'th number in the Fibonacci sequence.
 
 =head2 probab_prime
 
-  $x = Math::GMP->new(7);
-  $x->probab_prime(10);
+  my $x = Math::GMP->new(7);
+  my $is_prime_verdict = $x->probab_prime(10);
 
 Probabilistically determines if the number is a prime. Argument is the number
 of checks to perform. Returns 0 if the number is definitely not a prime,
 1 if it may be, and 2 if it definitely is a prime.
 
+=head2 $x->add_ui_gmp($n)
+
+Adds to $x and mutates it in-place. $n must be a regular non-GMP, positive,
+integer.
+
+=head2 ($quotient, $remainder) = $x->bdiv($y);
+
+  my $x = Math::GMP->new(7);
+  my ($quo, $rem) = $x->bdiv(3);
+
+Returns both the division and the modulo of an integer division operation.
+
+=head2 my $ret = $x->div_2exp_gmp($n);
+
+  my $x = Math::GMP->new(200);
+  my $ret = $x->div_2exp_gmp(2);
+
+Returns a right-shift of the Math::GMP object by an unsigned regular integer.
+Also look at blshift() .
+
+=head2 my $str = $x->get_str_gmp($base)
+
+  my $init_n = 3 * 7 + 2 * 7 * 7 + 6 * 7 * 7 * 7;
+  my $x = Math::GMP->new($init_n);
+  my $ret = $x->get_str_gmp(7);
+
+  print $ret; # Prints "6230".
+
+Returns a string representation of the number in base $base.
+
+=head2 my $clone = $x->gmp_copy()
+
+Returns a copy of $x that can be modified without affecting the original.
+
+=head2 gcd()
+
+An alias to bgcd() .
+
+=head2 lcm()
+
+An alias to blcm() .
+
+=head2 constant
+
+For internal use. B<Do not use directly>.
+
+=head2 destroy
+
+For internal use. B<Do not use directly>.
+
 =head1 BUGS
 
 As of version 1.0, Math::GMP is mostly compatible with the old
